Disable tessellation instead of CCPR in GrClipStack_SWMask

Change-Id: Ide987cebc40e7175d581c96977eea6acd76b5cff
Reviewed-on: https://skia-review.googlesource.com/c/skia/+/419076
Reviewed-by: Michael Ludwig <michaelludwig@google.com>
Commit-Queue: Chris Dalton <csmartdalton@google.com>
diff --git a/tests/GrClipStackTest.cpp b/tests/GrClipStackTest.cpp
index d58b823..5dffbf8 100644
--- a/tests/GrClipStackTest.cpp
+++ b/tests/GrClipStackTest.cpp
@@ -1954,15 +1954,15 @@
     }
 }
 
-// Must disable CCPR in order to trigger SW mask generation when the clip stack is applied.
-static void only_allow_default(GrContextOptions* options) {
+// Must disable tessellation in order to trigger SW mask generation when the clip stack is applied.
+static void disable_tessellation_atlas(GrContextOptions* options) {
     options->fGpuPathRenderers = GpuPathRenderers::kNone;
-    options->fDisableCoverageCountingPaths = true;
+    options->fAvoidStencilBuffers = true;
 }
 
 DEF_GPUTEST_FOR_CONTEXTS(GrClipStack_SWMask,
                          sk_gpu_test::GrContextFactory::IsRenderingContext,
-                         r, ctxInfo, only_allow_default) {
+                         r, ctxInfo, disable_tessellation_atlas) {
     GrDirectContext* context = ctxInfo.directContext();
     std::unique_ptr<GrSurfaceDrawContext> rtc = GrSurfaceDrawContext::Make(
             context, GrColorType::kRGBA_8888, nullptr, SkBackingFit::kExact, kDeviceBounds.size(),